Package: PieGlyph
Title: Axis Invariant Scatter Pie Plots
Version: 1.1.0
Authors@R: 
    c(person("Rishabh", "Vishwakarma", email = "vishwakr@tcd.ie", role = c("aut", "cre"),
             comment = c(ORCID = "0000-0002-4847-3494")),
      person("Caroline", "Brophy", role = "aut"),
      person("Catherine", "Hurley", role = "aut"))
Description: Extends 'ggplot2' to help replace points in a scatter plot with pie-chart glyphs showing the relative proportions of different categories. The pie glyphs are independent of the axes and plot dimensions, to prevent distortions when the plot dimensions are changed.
License: GPL (>= 3)
Encoding: UTF-8
Imports: ggplot2, dplyr, tidyr, rlang, ggiraph, ggforce, purrr,
        forcats, plyr, grid, scales, cli, utils
Suggests: spelling, ranger, maps, cowplot, mapproj, knitr, rmarkdown,
        testthat (>= 3.0.0), vdiffr
RoxygenNote: 7.3.2
VignetteBuilder: knitr
URL: https://rishvish.github.io/PieGlyph/,
        https://github.com/rishvish/PieGlyph
BugReports: https://github.com/rishvish/PieGlyph/issues
Config/testthat/edition: 3
Language: en-US
NeedsCompilation: no
Packaged: 2025-08-22 18:20:46 UTC; RVISHWAK
Author: Rishabh Vishwakarma [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4847-3494>),
  Caroline Brophy [aut],
  Catherine Hurley [aut]
Maintainer: Rishabh Vishwakarma <vishwakr@tcd.ie>
Repository: CRAN
Date/Publication: 2025-08-22 18:50:11 UTC
Built: R 4.6.0; ; 2026-04-26 17:39:26 UTC; unix
